@@ -1,3 +1,6 @@
+#ifndef _WEBPAGES_H_
+#define _WEBPAGES_H_ 1
+
 #define SIZE_OF_RESTRICTIP               20
 #define SIZE_OF_PASSWORD                 20
 #define SIZE_OF_EVENTIDMATCH     256
@@ -60,79 +63,81 @@
 
 
 // The following structure has been defined to cater for the 'config' registry settings
-struct  Reg_Config
-{
-	char	str_ClientName[SIZE_OF_CLIENTNAME];
-	char	str_NetworkDestination[SIZE_OF_DESTINATION];
-	int		dw_DestPort;
-	char	str_FileDestination[SIZE_OF_DESTINATION];
-	int		dw_stdout;
+struct Reg_Config {
+	char str_ClientName[SIZE_OF_CLIENTNAME];
+	char str_NetworkDestination[SIZE_OF_DESTINATION];
+	int dw_DestPort;
+	char str_FileDestination[SIZE_OF_DESTINATION];
+	int dw_stdout;
 };
 
-struct Reg_Remote
-{
-        int   dw_Allow;
-        int   dw_WebPort;
-        int   dw_Restrict;
-        char  str_RestrictIP[SIZE_OF_RESTRICTIP];
-        int   dw_Password;
-        char  str_Password[SIZE_OF_PASSWORD];
+struct Reg_Remote {
+	int dw_Allow;
+	int dw_WebPort;
+	int dw_Restrict;
+	char str_RestrictIP[SIZE_OF_RESTRICTIP];
+	int dw_Password;
+	char str_Password[SIZE_OF_PASSWORD];
 };
 
-struct Reg_Objective
-{
-        char    str_critic[SIZE_OF_CRITICALITY];
-        char    str_event_type[SIZE_OF_EVENTLOG];
-        char    str_eventid_match[SIZE_OF_EVENTIDMATCH];
-        char    str_user_match[SIZE_OF_USERMATCH];
-        char    str_general_match[SIZE_OF_GENERALMATCH];
-        char    str_user_match_type[SIZE_OF_USER_MATCH_TYPE];
+struct Reg_Objective {
+	char str_critic[SIZE_OF_CRITICALITY];
+	char str_event_type[SIZE_OF_EVENTLOG];
+	char str_eventid_match[SIZE_OF_EVENTIDMATCH];
+	char str_user_match[SIZE_OF_USERMATCH];
+	char str_general_match[SIZE_OF_GENERALMATCH];
+	char str_user_match_type[SIZE_OF_USER_MATCH_TYPE];
 };
 
 
-// int		HandleWebPages(char *HTTPBuffer,char *HTTPOutputBuffer,int size);
-int		HandleWebPages(char *HTTPBuffer,char *HTTPOutputBuffer,int size,int http_listen_socket, int http_message_socket);
-int		Status_Page(char *source, char *dest, int size);
-int		DefaultHeader(char *source, char *dest, int size);
-int		DisplayTextHeader(int http_socket);
+// int          HandleWebPages(char *HTTPBuffer,char *HTTPOutputBuffer,int size);
+int HandleWebPages(char *HTTPBuffer, char *HTTPOutputBuffer, int size,
+		   int http_listen_socket, int http_message_socket);
+int Status_Page(char *source, char *dest, int size);
+int DefaultHeader(char *source, char *dest, int size);
+int DisplayTextHeader(int http_socket);
 
-int		Network_Config(char *source, char *dest, int size);
-int		Remote_Config(char *source, char *dest, int size);
-int		Remote_Set(char *source, char *dest, int size);
-int		Objective_Config(char *source, char *dest, int size);
-int		DefaultFooter(char *source, char *dest, int size);
+int Network_Config(char *source, char *dest, int size);
+int Remote_Config(char *source, char *dest, int size);
+int Remote_Set(char *source, char *dest, int size);
+int Objective_Config(char *source, char *dest, int size);
+int DefaultFooter(char *source, char *dest, int size);
 
-int		InterSectImage(char *source, char *dest, int size);
-int		Objective_Display(char *source, char *dest, int size);
-// int		Restart(char *source, char *dest, int size);
-int		Restart(char *source, char *dest, int size, int one, int two);
-int		Network_Set(char *source, char *dest, int size);
-int		Objective_Result(char *, char *, int);
+int InterSectImage(char *source, char *dest, int size);
+int Objective_Display(char *source, char *dest, int size);
+// int          Restart(char *source, char *dest, int size);
+int Restart(char *source, char *dest, int size, int one, int two);
+int Network_Set(char *source, char *dest, int size);
+int Objective_Result(char *, char *, int);
 
-FILE *	Find_First_Objective();
-int		Get_Next_Objective(FILE * configfile, struct Reg_Objective *objective);
-int		Close_Objective_File(FILE *configfile);
+FILE *Find_First_Objective();
+int Get_Next_Objective(FILE * configfile, struct Reg_Objective *objective);
+int Close_Objective_File(FILE * configfile);
 
-int     ReadObjectives();
-void    DestroyList(void);
-int		debracket(char *source, char *dest, int length);
-int		ShowUsers(int http_socket);
-int		ShowGroups(int http_socket);
-int		ShowGroupMembers(int http_socket);
+int ReadObjectives();
+void DestroyList(void);
+int debracket(char *source, char *dest, int length);
+int ShowUsers(int http_socket);
+int ShowGroups(int http_socket);
+int ShowGroupMembers(int http_socket);
 
 
 // Stuff we use from webserver.h
-int		base64decode(char *dest, char *src, int l);
-char *	GetNextArgument(char *source,char *destvar,int varlength,char *destval,int vallength);
+int base64decode(char *dest, char *src);
+char *GetNextArgument(char *source, char *destvar, int varlength,
+		      char *destval, int vallength);
 
-void *	Load_Config_File();
-void	Clear_Config_File(void *location);
-int		Grab_RAMConfig_Line(char *source, char *dest, int size);
+void *Load_Config_File();
+int Read_Config_From_File(struct Reg_Config *);
+void Clear_Config_File(void *location);
+int Grab_RAMConfig_Line(char *source, char *dest, int size);
 
-int		getnetwork(char *string, char *host,int length);
+int getnetwork(char *string, char *host, int length);
 
-int		Read_Remote_From_File(struct Reg_Remote *remote_struct);
+int Read_Remote_From_File(struct Reg_Remote *remote_struct);
 
-int		iswebfilename(char *string);
-int		isstdout(char *string);
-int		isnetwork(char *string);
+int iswebfilename(char *string);
+int isstdout(char *string);
+int isnetwork(char *string);
+
+#endif				// _WEBPAGES_H_
